@@ -58,3 +58,27 @@ def replace(old, new, s, count=-1):
         return s.replace(old, new, count)
     else:
         return s.replace(old, new)
+
+@pipeable
+def startswith(prefix, S, *, start = None, end = None):
+    '''Return True if S starts with the specified prefix, False otherwise.
+
+       With optional start, test S beginning at that position.
+       With optional end, stop comparing S at that position.
+       prefix can also be a tuple of strings to try.
+
+       Args:
+            - prefix - pattern to check for
+            - S - String to be checked
+            - start - optional index for starting the search
+            - end - option end index
+    '''
+    if start and end:
+        return S.startswith(prefix, start, end)
+    elif end:
+        raise TypeError('Cannot specify and end without also specifying start')
+    elif start:
+        return S.startswith(prefix, start)
+    else:   
+        return S.startswith(prefix)
+
